# Changelog

## 1.6.0 (2025-07-09)

Full Changelog: [v1.5.0...v1.6.0](https://github.com/coingecko/coingecko-python/compare/v1.5.0...v1.6.0)

### Features

* **api:** api update ([e9e6d07](https://github.com/coingecko/coingecko-python/commit/e9e6d07786128ed47006a294158227ad94a4c9b8))

## 1.5.0 (2025-07-09)

Full Changelog: [v1.4.3...v1.5.0](https://github.com/coingecko/coingecko-python/compare/v1.4.3...v1.5.0)

### Features

* **api:** api update ([b41c660](https://github.com/coingecko/coingecko-python/commit/b41c660bac9c294c73b8a86de00df0880dafa01d))


### Chores

* **internal:** bump pinned h11 dep ([13baf6c](https://github.com/coingecko/coingecko-python/commit/13baf6ccd984b531b02c8db73fe068b992169895))
* **package:** mark python 3.13 as supported ([8b2928d](https://github.com/coingecko/coingecko-python/commit/8b2928d3d25fb242e9e06c31c368f968c5926a2f))

## 1.4.3 (2025-07-08)

Full Changelog: [v1.4.2...v1.4.3](https://github.com/coingecko/coingecko-python/compare/v1.4.2...v1.4.3)

### Chores

* **internal:** codegen related update ([248b684](https://github.com/coingecko/coingecko-python/commit/248b68401d0ec618acab47331b28e2b76fd8c4ce))

## 1.4.2 (2025-07-02)

Full Changelog: [v1.4.1...v1.4.2](https://github.com/coingecko/coingecko-python/compare/v1.4.1...v1.4.2)

### Bug Fixes

* **ci:** correct conditional ([7726945](https://github.com/coingecko/coingecko-python/commit/7726945a5743e28a4648e02bf4876f0a1b87f75c))


### Chores

* **ci:** change upload type ([2ef9872](https://github.com/coingecko/coingecko-python/commit/2ef9872675567a711712da5d1d097482898cd68d))

## 1.4.1 (2025-06-28)

Full Changelog: [v1.4.0...v1.4.1](https://github.com/coingecko/coingecko-python/compare/v1.4.0...v1.4.1)

### Bug Fixes

* **ci:** release-doctor — report correct token name ([62a033e](https://github.com/coingecko/coingecko-python/commit/62a033edbd1724b28675b56b93c30f2b08d774f1))


### Chores

* **ci:** only run for pushes and fork pull requests ([5db6eab](https://github.com/coingecko/coingecko-python/commit/5db6eab0f596f4e670280e231707f63ea82688b6))
* **tests:** skip some failing tests on the latest python versions ([f5e4873](https://github.com/coingecko/coingecko-python/commit/f5e487351a37cca5de41139c656a1c48a09bf6ec))

## 1.4.0 (2025-06-23)

Full Changelog: [v1.3.0...v1.4.0](https://github.com/coingecko/coingecko-python/compare/v1.3.0...v1.4.0)

### Features

* **api:** api update ([cad480f](https://github.com/coingecko/coingecko-python/commit/cad480ff6c82385a647f9b4f8340e0e16588f7bb))

## 1.3.0 (2025-06-21)

Full Changelog: [v1.2.1...v1.3.0](https://github.com/coingecko/coingecko-python/compare/v1.2.1...v1.3.0)

### Features

* **client:** add support for aiohttp ([f2c6437](https://github.com/coingecko/coingecko-python/commit/f2c64372ad045019cbc51c9f9abf3a9c3df8633e))

## 1.2.1 (2025-06-19)

Full Changelog: [v1.2.0...v1.2.1](https://github.com/coingecko/coingecko-python/compare/v1.2.0...v1.2.1)

### Bug Fixes

* **tests:** fix: tests which call HTTP endpoints directly with the example parameters ([f7d45a8](https://github.com/coingecko/coingecko-python/commit/f7d45a825ab455b05242e396da0dfce74eeed44c))


### Chores

* **ci:** enable for pull requests ([a0ed478](https://github.com/coingecko/coingecko-python/commit/a0ed4785eb7e04cbd2a948f31123f0981020c5eb))
* **internal:** update conftest.py ([12b1700](https://github.com/coingecko/coingecko-python/commit/12b170018f682c36ef7b12c85eb66f368fd7a535))
* **readme:** update badges ([815ee9f](https://github.com/coingecko/coingecko-python/commit/815ee9f4c7a155eca1ef5775e188a9d48f0418ea))
* **tests:** add tests for httpx client instantiation & proxies ([352858a](https://github.com/coingecko/coingecko-python/commit/352858ae3fdb260cb638b23e745c1fb9e06dc6d1))


### Documentation

* **client:** fix httpx.Timeout documentation reference ([1b205fd](https://github.com/coingecko/coingecko-python/commit/1b205fd1bb9ca50eaef4ef5139f5a21f3fb4c655))

## 1.2.0 (2025-06-13)

Full Changelog: [v1.1.0...v1.2.0](https://github.com/coingecko/coingecko-python/compare/v1.1.0...v1.2.0)

### Features

* **api:** manual updates ([7ff4d0d](https://github.com/coingecko/coingecko-python/commit/7ff4d0d6989cc21fcc41f383b0483d45484d14e7))

## 1.1.0 (2025-06-13)

Full Changelog: [v1.0.1...v1.1.0](https://github.com/coingecko/coingecko-python/compare/v1.0.1...v1.1.0)

### Features

* **api:** Update example response ([ea77eac](https://github.com/coingecko/coingecko-python/commit/ea77eacb32e83b5adf9935eae92dc9bbe29e5a69))


### Bug Fixes

* **client:** correctly parse binary response | stream ([7df7dc4](https://github.com/coingecko/coingecko-python/commit/7df7dc4a59b037a167ed63c849c08436aac08bde))


### Chores

* **tests:** run tests in parallel ([115a0dc](https://github.com/coingecko/coingecko-python/commit/115a0dcd97d26d7005a72a47c24c49bc4b0713b3))

## 1.0.1 (2025-06-10)

Full Changelog: [v1.0.0...v1.0.1](https://github.com/coingecko/coingecko-python/compare/v1.0.0...v1.0.1)

### Chores

* **internal:** version bump ([8773836](https://github.com/coingecko/coingecko-python/commit/87738364b7ecbf1c534528067548d5ad75282809))

## 1.0.0 (2025-06-10)

Full Changelog: [v0.1.0-alpha.7...v1.0.0](https://github.com/coingecko/coingecko-python/compare/v0.1.0-alpha.7...v1.0.0)

### Chores

* update SDK settings ([4fd9a80](https://github.com/coingecko/coingecko-python/commit/4fd9a80c750f4de6facf297537ae9bb1b267ceca))

## 0.1.0-alpha.7 (2025-06-08)

Full Changelog: [v0.1.0-alpha.6...v0.1.0-alpha.7](https://github.com/coingecko/coingecko-python/compare/v0.1.0-alpha.6...v0.1.0-alpha.7)

### Features

* **api:** Update to coingecko_sdk ([262a767](https://github.com/coingecko/coingecko-python/commit/262a76703b119bcc2648db0e21a63d9400a8719c))

## 0.1.0-alpha.6 (2025-06-07)

Full Changelog: [v0.1.0-alpha.5...v0.1.0-alpha.6](https://github.com/coingecko/coingecko-python/compare/v0.1.0-alpha.5...v0.1.0-alpha.6)

### Features

* **api:** api update ([9f7378c](https://github.com/coingecko/coingecko-python/commit/9f7378c9775aa51e345033dded23a26e65878b97))
* **api:** New endpoints ([fd3b486](https://github.com/coingecko/coingecko-python/commit/fd3b486f6528d71be7df3a5a9186ace2742819bd))

## 0.1.0-alpha.5 (2025-06-03)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/coingecko/coingecko-python/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* **client:** add follow_redirects request option ([f01e996](https://github.com/coingecko/coingecko-python/commit/f01e99674f5b0e7d243395588ad6a87e88eda894))


### Chores

* **docs:** remove reference to rye shell ([5c72fbf](https://github.com/coingecko/coingecko-python/commit/5c72fbf675d06b2b8ccfd36604d01cc28ad9a637))

## 0.1.0-alpha.4 (2025-06-02)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/coingecko/coingecko-python/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Features

* **api:** update via SDK Studio ([0c72a75](https://github.com/coingecko/coingecko-python/commit/0c72a7510464ed2bc0620d1ed64b6ab40f7145b7))

## 0.1.0-alpha.3 (2025-05-29)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/coingecko/coingecko-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** update via SDK Studio ([0812f21](https://github.com/coingecko/coingecko-python/commit/0812f2163205be4e48486f201ab979b78593e9a1))

## 0.1.0-alpha.2 (2025-05-28)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/coingecko/coingecko-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** update via SDK Studio ([3869350](https://github.com/coingecko/coingecko-python/commit/3869350a197c6e83fe5c68199ea6047bc177cf14))

## 0.1.0-alpha.1 (2025-05-28)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/coingecko/coingecko-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([2b17650](https://github.com/coingecko/coingecko-python/commit/2b17650480b4d839844a1fb09a7a1eba74a48966))
* **api:** update via SDK Studio ([c7b2f6c](https://github.com/coingecko/coingecko-python/commit/c7b2f6c7a949b1ac299601712e291dd22cad5d20))
* **api:** update via SDK Studio ([2e88eda](https://github.com/coingecko/coingecko-python/commit/2e88edae53fe8c78f114d83a069bdcd90e1505ef))


### Chores

* update SDK settings ([616d906](https://github.com/coingecko/coingecko-python/commit/616d9066a6514fb0f9d33dd941a135bcf84700ca))
